pycocoa.panels.BrowserPanel

Package pycocoa :: Module panels :: Class BrowserPanel |
[frames] | no frames]

# Class BrowserPanel

      object --+
               |
    bases._Type0 --+
                   |
        bases._Type1 --+
                       |
            bases._Type2 --+
                           |
                          BrowserPanel

Python Type to show a URL or file.

Instance Methods
__init__(self, name=None, title='') New BrowserPanel, a browser. |
open(self, url, tab=False) Open a new window or tab in the browser. |
Inherited from `bases._Type2`: `__str__` Inherited from `bases._Type0`: `__repr__`, `type2strepr` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| browser Get the browser instance (`browser type`).
Inherited from `bases._Type2`: `title` Inherited from `bases._Type1`: `NSdelegate`, `app` Inherited from `bases._Type0`: `NS`, `NSDelegate`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__(self, name=None, title='') (Constructor) |
New BrowserPanel, a browser. Parameters: `name` - Browser type (`str` or `None` for default). `title` - The panel name (`str`). Raises: `ValueError` - No browser type name. Overrides: object.__init__ See Also: Browser types.

### open(self, url, tab=False) |
Open a new window or tab in the browser. Parameters: `url` - The URL to open (`str`). `tab` - New tab (`bool`), new window otherwise. Returns: Parsed url as `ParseResult`. Raises: `ValueError` - Scheme of url not 'http', 'https' or 'file'.

Property Details

### browser Get the browser instance (`browser type`). Get Method: browser(self) - Get the browser instance (`browser type`). Set Method: Read_Only(inst, value) - Throws an `AttributeError`, always.